@@ -34,6 +34,7 @@ dest_apps_dir="${DESTDIR}${app_prefix}"
 app_data=${app_data:=/opt/puppetlabs/server/data/${real_name}}
 app_logdir=${app_logdir:=/var/log/puppetlabs/${real_name}}
 system_config_dir=${system_config_dir:=${app_prefix}/config}
+needrestart_confdir=${needrestart_dir:=/etc/needrestart/conf.d}
 
 
 ##################
@@ -142,8 +143,8 @@ function task_install_docs_deb {
 # install docs for rpm based systems
 function task_install_docs_rpm {
   if [ -d ext/docs ]; then
-    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-7.11.0"
-    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-7.11.0"
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.6.0"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.6.0"
   fi
 }
 
@@ -166,13 +167,13 @@ function task_install {
     install -m 0644 ext/config/conf.d/puppetserver.conf "${DESTDIR}${projconfdir}/conf.d/puppetserver.conf"
     install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
     install -m 0644 ext/config/logback.xml "${DESTDIR}${projconfdir}/logback.xml"
+    install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
     install -m 0644 ext/config/conf.d/global.conf "${DESTDIR}${projconfdir}/conf.d/global.conf"
     install -m 0644 ext/config/conf.d/web-routes.conf "${DESTDIR}${projconfdir}/conf.d/web-routes.conf"
     install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
     install -m 0644 ext/config/conf.d/metrics.conf "${DESTDIR}${projconfdir}/conf.d/metrics.conf"
     install -m 0644 ext/config/conf.d/ca.conf "${DESTDIR}${projconfdir}/conf.d/ca.conf"
     install -m 0644 ext/config/conf.d/webserver.conf "${DESTDIR}${projconfdir}/conf.d/webserver.conf"
-    install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
 
     install -d -m 0755 "${dest_apps_dir}/scripts"
     install -m 0755 install.sh "${dest_apps_dir}/scripts"
@@ -185,15 +186,15 @@ function task_install {
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
+    install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
+    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
     install -m 0755 ext/cli/gem "${dest_apps_dir}/cli/apps/gem"
+    install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
+    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
+    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
     install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
     install -m 0755 ext/cli/ca "${dest_apps_dir}/cli/apps/ca"
-    install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
-    install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
-    install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
-    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
     install -m 0755 ext/cli/dropsonde "${dest_apps_dir}/cli/apps/dropsonde"
-    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
 
 if [ -e "ext/cli_defaults/cli-defaults.sh" ]; then
     install -m 0755 ext/cli_defaults/cli-defaults.sh "${dest_apps_dir}/cli/"
@@ -268,6 +269,8 @@ function task_systemd_deb {
     fi
     install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
     install -m 0644 ext/puppetserver.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetserver.conf"
+    install -d -m 0755 "${DESTDIR}${needrestart_confdir}"
+    install -m 0644 ext/puppetserver.needrestart.conf "${DESTDIR}${needrestart_confdir}/puppetserver.conf"
 }
 
 function task_service_account {
