@@ -943,14 +943,25 @@
                               :body
                               slurp
                               (validated-body CatalogRequestV4))]
-      {:status 200
-       :headers {"Content-Type" "application/json"}
-       :body (json/encode
-              (jruby-protocol/compile-catalog jruby-service
-                                              (:jruby-instance request)
-                                              (assoc request-options
-                                                     "code_id"
-                                                     (current-code-id-fn (get request-options "environment")))))})))
+      (try
+        {:status  200
+         :headers {"Content-Type" "application/json"}
+         :body    (json/encode
+                    (jruby-protocol/compile-catalog jruby-service
+                                                    (:jruby-instance request)
+                                                    (assoc request-options
+                                                      "code_id"
+                                                      (current-code-id-fn (get request-options "environment")))))}
+        (finally
+          ;; don't let any exceptions escape
+          (try
+            (ps-common/record-action {:type    :action
+                                      :targets [(get request-options "certname")]
+                                      :meta    {:type  :certificate
+                                                :what  :compile-catalog
+                                                :where :v4}})
+            (catch Throwable e
+              (log/info e (i18n/trs "Failed to report action")))))))))
 
 (defn parse-project-compile-data
   "Parse data required to compile a catalog inside a project. Data required includes
@@ -1051,7 +1062,8 @@
   "v3 route tree for the ruby side of the master service."
   [request-handler :- IFn
    bolt-builtin-content-dir :- (schema/maybe [schema/Str])
-   bolt-projects-dir :- (schema/maybe schema/Str)]
+   bolt-projects-dir :- (schema/maybe schema/Str)
+   certname :- schema/Str]
   (comidi/routes
    (comidi/GET ["/node/" [#".*" :rest]] request
                (request-handler request))
@@ -1072,7 +1084,8 @@
    (comidi/GET ["/catalog/" [#".*" :rest]] request
                (request-handler (assoc request :include-code-id? true)))
    (comidi/POST ["/catalog/" [#".*" :rest]] request
-                (request-handler (assoc request :include-code-id? true)))
+               (let [request-handler (ringutils/wrap-with-certname-as-compiler request-handler certname)]
+                 (request-handler (assoc request :include-code-id? true))))
    (comidi/PUT ["/facts/" [#".*" :rest]] request
                (request-handler request))
    (comidi/PUT ["/report/" [#".*" :rest]] request
@@ -1178,9 +1191,10 @@
    wrap-with-jruby-queue-limit :- IFn
    boltlib-path :- (schema/maybe [schema/Str])
    bolt-builtin-content-dir :- (schema/maybe [schema/Str])
-   bolt-projects-dir :- (schema/maybe schema/Str)]
+   bolt-projects-dir :- (schema/maybe schema/Str)
+   certname :- schema/Str]
   (comidi/context "/v3"
-                  (v3-ruby-routes ruby-request-handler bolt-builtin-content-dir bolt-projects-dir)
+                  (v3-ruby-routes ruby-request-handler bolt-builtin-content-dir bolt-projects-dir certname)
                   (comidi/wrap-routes
                    (v3-clojure-routes jruby-service
                                       get-code-content-fn
@@ -1292,7 +1306,8 @@
    environment-class-cache-enabled :- schema/Bool
    boltlib-path :- (schema/maybe [schema/Str])
    bolt-builtin-content-dir :- (schema/maybe [schema/Str])
-   bolt-projects-dir :- (schema/maybe schema/Str)]
+   bolt-projects-dir :- (schema/maybe schema/Str)
+   certname :- schema/Str]
   (comidi/routes
    (v3-routes ruby-request-handler
               clojure-request-wrapper
@@ -1303,7 +1318,8 @@
               wrap-with-jruby-queue-limit
               boltlib-path
               bolt-builtin-content-dir
-              bolt-projects-dir)
+              bolt-projects-dir
+              certname)
    (v4-routes clojure-request-wrapper
               jruby-service
               wrap-with-jruby-queue-limit
@@ -1366,7 +1382,8 @@
    environment-class-cache-enabled :- schema/Bool
    boltlib-path :- (schema/maybe [schema/Str])
    bolt-builtin-content-dir :- (schema/maybe [schema/Str])
-   bolt-projects-dir :- (schema/maybe schema/Str)]
+   bolt-projects-dir :- (schema/maybe schema/Str)
+   certname :- schema/Str]
   (let [ruby-request-handler (wrap-middleware handle-request
                                               wrap-with-authorization-check
                                               puppet-version)
@@ -1384,7 +1401,8 @@
                  environment-class-cache-enabled
                  boltlib-path
                  bolt-builtin-content-dir
-                 bolt-projects-dir)))
+                 bolt-projects-dir
+                 certname)))
 
 (def MasterStatusV1
   {(schema/optional-key :experimental) {:http-metrics [http-metrics/RouteSummary]
